@@ -5,8 +5,6 @@
     Copyright (C) 1997-2000 Peter Putzer
                             putzer@kde.org
 
-	$Id: TopWidget.cpp,v 1.121 2004/07/04 09:46:39 binner Exp $
-
     This program is free software; you can redistribute it and/or modify
     it under the terms of version 2 of the GNU General Public License
     as published by the Free Software Foundation.
@@ -18,7 +16,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
 
 /****************************************************************
@@ -296,16 +294,15 @@ bool KSVTopLevel::queryExit() {
   uint res = KMessageBox::Yes;
 
   if (mChanged) {
-    res = KMessageBox::warningYesNo(kapp->mainWidget(),
+    res = KMessageBox::warningContinueCancel(kapp->mainWidget(),
 				    i18n("There are unsaved changes. Are you sure you want to quit?"),
 				    i18n("Quit"),
-				    KStdGuiItem::quit(),
-				    KStdGuiItem::cancel());
+				    KStdGuiItem::quit());
 
   }
 
   qApp->processEvents();
-  return res == KMessageBox::Yes;
+  return res == KMessageBox::Continue;
 }
 
 void KSVTopLevel::slotClearChanges()
@@ -324,15 +321,14 @@ void KSVTopLevel::slotClearChanges()
 }
 
 void KSVTopLevel::slotAcceptChanges() {
-  if (KMessageBox::Yes ==
-      KMessageBox::warningYesNo(kapp->mainWidget(),
+  if (KMessageBox::Continue ==
+      KMessageBox::warningContinueCancel(kapp->mainWidget(),
 				i18n("You're about to save the changes made to your init "
 				     "configuration. Wrong settings can "
 				     "make your system hang on startup.\n"
 				     "Do you wish to continue?"),
 				i18n("Save Configuration"),
-				KStdGuiItem::save(),
-				KStdGuiItem::cancel()))
+				KStdGuiItem::save()))
     {
       mView->slotWriteSysV();
       initView();
